@@ -41,6 +41,7 @@ class EventWaiter:
       if self.done:
          return True
       if self.timeout is not None and (time.perf_counter() - self.start) > self.timeout:
+         print(util.full_exc_info())
          raise aio.TimeoutError()
       if await self.check(event):
          await self.queue.put(event)
@@ -57,7 +58,7 @@ class EventWaiter:
          raise GeneratorExit()
 
 
-class Eventful(util.AutoRepr):
+class Eventful:
    EventableFunc: ty.TypeAlias = ty.Callable[[Event], ty.Awaitable[ty.Optional[bool]]]
    f: EventableFunc
 
@@ -90,7 +91,7 @@ class Eventful(util.AutoRepr):
       return __decompose_wrapper
 
 
-class EventMuxer(util.AutoRepr):
+class EventMuxer:
    def __init__(self, name: str, router: EventRouter):
       self.name = name
       self.router = router
@@ -120,17 +121,24 @@ class EventMuxer(util.AutoRepr):
    def register(self, eventful: Eventful):
       self.eventfuls.add(eventful)
 
+   def __repr__(self):
+      return f"EventMuxer(router={self.router.name}, eventfuls={[ev.f.__name__ for ev in self.eventfuls]})"
+
    def __str__(self):
       return f"EventMuxer {self.name}:\n{len(self.eventfuls)} eventfuls"
 
 
-class EventRouterHost(util.AutoRepr):
+class EventRouterHost:
    def __init__(self, name: str = "Unnamed"):
       self.name = name.lower()
       self.routers: ty.Dict[str, ty.List[EventRouter]] = clc.defaultdict(list)
 
-   def __str__(self):
-      return f"EventRouterHost {self.name} | Routers: {[r for r in self.routers]}"
+   def __repr__(self):
+      router_block = ["\t" + f"{router}" + "\n" for router in self.routers.values()]
+      return f"EventRouterHost(name={self.name}, routers={router_block})"
+
+   # def __str__(self):
+   #    return f"EventRouterHost {self.name} | Routers: {[r for r in self.routers]}"
 
    def register(self, router: EventRouter) -> None:
       if router.name in self.routers:
@@ -196,3 +204,6 @@ class EventRouter(util.AutoRepr):
 
    def __str__(self):
       return f"[Router: {self.name} |  <{self.muxers}>]"
+
+   def __repr__(self):
+      return f"Router(name={self.name}, muxers={[m for m in self.muxers]})"
\ No newline at end of file
